@@ -23,18 +23,18 @@ class RateLimitMixin(object):
             counts = self.get_counters(request)
             if sum(counts.values()) >= self.requests:
                 logger.warning(
-                    "Login rate-limit reached: username '{0}', IP {1}".format(
+                    u"Login rate-limit reached: username '{0}', IP {1}".format(
                         username, request.META['REMOTE_ADDR']
                     )
                 )
                 raise RateLimitException('Rate-limit reached', counts)
         else:
-            logger.warning("No request passed to the backend, unable to "
-                           "rate-limit. Username was '%s'" % username)
+            logger.warning(u"No request passed to the backend, unable to "
+                           u"rate-limit. Username was '%s'" % username)
         user = super(RateLimitMixin, self).authenticate(username, password)
         if user is None and request is not None:
             logger.info(
-                "Login failed: username '{0}', IP {1}".format(
+                u"Login failed: username '{0}', IP {1}".format(
                     username,
                     request.META['REMOTE_ADDR'],
                 )
