@@ -4,7 +4,8 @@ from .. import admin
 from ..views import login
 
 
-urlpatterns = patterns('',
+urlpatterns = patterns(
+    '',
     url(r'^login/$', login,
         {'template_name': 'admin/login.html'}, name='login'),
     url(r'^admin/', include(admin.site.urls)),
